==> dde-tray-loader_0.0.10.tar.xz: BUILD/plugins/dde-network-core/dock-tray-network-plugin/translations/dock-network-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>dde::network::DockContentWidget</name>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>網路檢測</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用藍牙功能，請先關閉&lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;飛行模式&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Disable airplane mode first if you want to connect to a wireless network</source>
        <translation>若要使用無線網路功能，請先關閉飛行模式</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>正在連線&quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; 已連接</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; 已斷開</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>未能加入&quot;%1&quot;，請檢查路由器或網路線。</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>未能加入&quot;%1&quot;，請嘗試靠近無線路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>連線失敗，未能加入&quot;%1&quot;，密碼不正確</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>連接&quot;%1&quot;需要密碼</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>&quot;%1&quot; 802.11 WLAN網路無法找到</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>連接“%1”需要登入後配置認證資訊</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰密碼</translation>
    </message>
    <message>
        <source>key</source>
        <translation>金鑰</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>代理密碼</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>組密碼</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>請輸入使用者名稱</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>請輸入網路名稱（SSID）</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>連 接</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Close wired connection</source>
        <translation>關閉有線網路</translation>
    </message>
    <message>
        <source>Open wired connection</source>
        <translation>開啟有線網路</translation>
    </message>
    <message>
        <source>Close wireless connection</source>
        <translation>關閉無線網路</translation>
    </message>
    <message>
        <source>Open wireless connection</source>
        <translation>開啟無線網路</translation>
    </message>
    <message>
        <source>Close network</source>
        <translation>關閉網路</translation>
    </message>
    <message>
        <source>Open network</source>
        <translation>開啟網路</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>網路關閉</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網路線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網路但無法訪問網路</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連線失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredDisabledItem</name>
    <message>
        <source>Wired network off</source>
        <translation>有線網路已關閉</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessDisabledItem</name>
    <message>
        <source>Wireless network off</source>
        <translation>無線網路已關閉</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>連線到隱藏網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>我的網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>其他網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
</TS>

==> dde-tray-loader_1.0.10.tar.xz: BUILD/plugins/dde-network-core/dock-tray-network-plugin/translations/dock-network-plugin_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>dde::network::DockContentWidget</name>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>網路檢測</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>若要使用藍牙功能，請先關閉&lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;飛行模式&lt;/a&gt; </translation>
    </message>
    <message>
        <source>Disable airplane mode first if you want to connect to a wireless network</source>
        <translation>若要使用無線網路功能，請先關閉飛行模式</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>正在連線&quot;%1&quot;</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; 已連接</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; 已斷開</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>未能加入&quot;%1&quot;，請檢查路由器或網路線。</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>未能加入&quot;%1&quot;，請嘗試靠近無線路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>連線失敗，未能加入&quot;%1&quot;，密碼不正確</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>連接&quot;%1&quot;需要密碼</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>&quot;%1&quot; 802.11 WLAN網路無法找到</translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>連接“%1”需要登入後配置認證資訊</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>私鑰密碼</translation>
    </message>
    <message>
        <source>key</source>
        <translation>金鑰</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>代理密碼</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>組密碼</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>請輸入使用者名稱</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>請輸入網路名稱（SSID）</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>連 接</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>關閉有線網路</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>開啟有線網路</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>關閉無線網路</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>開啟無線網路</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>關閉網路</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>開啟網路</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation>關閉VPN</translation>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation>開啟VPN</translation>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation>關閉系統代理</translation>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation>開啟系統代理</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>網路設定</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation>多個服務已開啟</translation>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation>已連接至：%1</translation>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation>系統代理已開啟</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>網路關閉</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入網路線</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在連線</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已連接網路但無法訪問網路</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>連線失敗</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP位址衝突</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>系統代理</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNControlItem</name>
    <message>
        <source>VPN</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>VPN配置未連接或連線失敗，請 &lt;a style=&quot;text-decoration: none;&quot;href=&quot;go to the control center&quot;&gt;前往控制中心 &lt;/a&gt;檢查</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>有線網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredDisabledItem</name>
    <message>
        <source>Wired network off</source>
        <translation>有線網路已關閉</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>無線網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessDisabledItem</name>
    <message>
        <source>Wireless network off</source>
        <translation>無線網路已關閉</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>連線到隱藏網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>我的網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>其他網路</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
</context>
</TS>
